@@ -88,18 +88,23 @@ def print_used_values(cfg, log):
     if "dataset" in cfg:
         log.info("Dataset parameters:")
 
-        if cfg["dataset"].single_cell:
-            log.info("  Single-cell mode")
-        elif cfg["dataset"].meta:
+        if options_storage.iontorrent:
+            log.info("  IonTorrent data")
+
+        if options_storage.meta:
             log.info("  Metagenomic mode")
-        elif cfg["dataset"].truseq:
-            log.info(" Illumina TruSeq mode")
+        elif options_storage.large_genome:
+            log.info("  Large genome mode")
+        elif options_storage.truseq_mode:
+            log.info("  Illumina TruSeq mode")
+        elif options_storage.rna:
+            log.info("  RNA-seq mode")
+        elif options_storage.single_cell:
+            log.info("  Single-cell mode")
         else:
             log.info("  Multi-cell mode (you should set '--sc' flag if input data"\
                      " was obtained with MDA (single-cell) technology"\
                      " or --meta flag if processing metagenomic dataset)")
-        if cfg["dataset"].iontorrent:
-            log.info("  IonTorrent data")
 
         log.info("  Reads:")
         dataset_data = pyyaml.load(open(cfg["dataset"].yaml_filename, 'r'))
@@ -124,14 +129,16 @@ def print_used_values(cfg, log):
             log.info("  k: automatic selection based on read length")
         else:
             print_value(cfg, "assembly", "iterative_K", "k")
-        if cfg["assembly"].careful:
-            log.info("  Mismatch careful mode is turned ON")
-        else:
-            log.info("  Mismatch careful mode is turned OFF")
+        if options_storage.plasmid:
+            log.info("  Plasmid mode is turned ON")
         if cfg["assembly"].disable_rr:
             log.info("  Repeat resolution is DISABLED")
         else:
             log.info("  Repeat resolution is enabled")
+        if options_storage.careful:
+            log.info("  Mismatch careful mode is turned ON")
+        else:
+            log.info("  Mismatch careful mode is turned OFF")
         if "mismatch_corrector" in cfg:
             log.info("  MismatchCorrector will be used")
         else:
@@ -179,10 +186,15 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                                       len(options_storage.SHORT_READS_TYPES.keys()) +
                                       len(options_storage.LONG_READS_TYPES))]  # "[{}]*num" doesn't work here!
 
+    # auto detecting SPAdes mode (rna, meta, etc) if it is not a rerun (--continue or --restart-from)
+    if secondary_filling or not options_storage.will_rerun(options):
+        mode = options_storage.get_mode()
+        if mode is not None:
+            options.append(('--' + mode, ''))
+
     # for parsing options from "previous run command"
     options_storage.continue_mode = False
     options_storage.k_mers = None
-
     for opt, arg in options:
         if opt == '-o':
             if not skip_output_dir:
@@ -190,13 +202,17 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                     support.error('-o option was specified at least twice')
                 options_storage.output_dir = abspath(expanduser(arg))
                 options_storage.dict_of_rel2abs[arg] = options_storage.output_dir
+                support.check_path_is_ascii(options_storage.output_dir, 'output directory')
         elif opt == "--tmp-dir":
             options_storage.tmp_dir = abspath(expanduser(arg))
             options_storage.dict_of_rel2abs[arg] = options_storage.tmp_dir
+            support.check_path_is_ascii(options_storage.tmp_dir, 'directory for temporary files')
         elif opt == "--configs-dir":
             options_storage.configs_dir = support.check_dir_existence(arg)
         elif opt == "--reference":
             options_storage.reference = support.check_file_existence(arg, 'reference', log)
+        elif opt == "--series-analysis":
+            options_storage.series_analysis = support.check_file_existence(arg, 'series-analysis', log)
         elif opt == "--dataset":
             options_storage.dataset_yaml_filename = support.check_file_existence(arg, 'dataset', log)
 
@@ -219,6 +235,12 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             options_storage.single_cell = True
         elif opt == "--meta":
             options_storage.meta = True
+        elif opt == "--large-genome":
+            options_storage.large_genome = True
+        elif opt == "--plasmid":
+            options_storage.plasmid = True
+        elif opt == "--rna":
+            options_storage.rna = True
         elif opt == "--iontorrent":
             options_storage.iontorrent = True
         elif opt == "--disable-gzip-output":
@@ -229,7 +251,7 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             options_storage.disable_rr = True
         elif opt == "--disable-rr:false":
             options_storage.disable_rr = False
-
+        
         elif opt == "--only-error-correction":
             if options_storage.only_assembler:
                 support.error('you cannot specify --only-error-correction and --only-assembler simultaneously')
@@ -310,9 +332,7 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             show_usage(0, show_hidden=True)
 
         elif opt == "--test":
-            options_storage.set_test_options()
-            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset/ecoli_1K_1.fq.gz"), dataset_data)
-            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset/ecoli_1K_2.fq.gz"), dataset_data)
+            options_storage.set_test_options()            
             #break
         elif opt == "--diploid":
             options_storage.diploid_mode = True
@@ -321,6 +341,14 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         else:
             raise ValueError
 
+    if options_storage.test_mode:
+        if options_storage.plasmid:
+            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset_plasmid/pl1.fq.gz"), dataset_data)
+            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset_plasmid/pl2.fq.gz"), dataset_data)
+        else:
+            support.add_to_dataset('-1', os.path.join(spades_home, "test_dataset/ecoli_1K_1.fq.gz"), dataset_data)
+            support.add_to_dataset('-2', os.path.join(spades_home, "test_dataset/ecoli_1K_2.fq.gz"), dataset_data)
+
     if not options_storage.output_dir:
         support.error("the output_dir is not set! It is a mandatory parameter (-o output_dir).", log)
     if not os.path.isdir(options_storage.output_dir):
@@ -337,6 +365,11 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
     if options_storage.meta:
         if options_storage.careful or options_storage.mismatch_corrector or options_storage.cov_cutoff != "off":
             support.error("you cannot specify --careful, --mismatch-correction or --cov-cutoff in metagenomic mode!", log)
+    if options_storage.rna:
+        if options_storage.careful:
+            support.error("you cannot specify --careful in RNA-Seq mode!", log)
+        if options_storage.k_mers and options_storage.k_mers != 'auto' and len(options_storage.k_mers) > 1:
+            support.error("you cannot specify multiple k-mer sizes in RNA-Seq mode!", log)
     if options_storage.continue_mode:
         return None, None
 
@@ -350,7 +383,6 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
                 existing_dataset_data = None
     if existing_dataset_data is not None:
         dataset_data = existing_dataset_data
-        options_storage.dataset_yaml_filename = processed_dataset_fpath
     else:
         if options_storage.dataset_yaml_filename:
             try:
@@ -362,12 +394,20 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         else:
             dataset_data = support.correct_dataset(dataset_data)
             dataset_data = support.relative2abs_paths(dataset_data, os.getcwd())
-        options_storage.dataset_yaml_filename = processed_dataset_fpath
-        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'))
+    options_storage.dataset_yaml_filename = processed_dataset_fpath
 
     support.check_dataset_reads(dataset_data, options_storage.only_assembler, log)
     if not support.get_lib_ids_by_type(dataset_data, spades_logic.READS_TYPES_USED_IN_CONSTRUCTION):
         support.error('you should specify at least one unpaired, paired-end, or high-quality mate-pairs library!')
+    if options_storage.rna:
+        if len(dataset_data) != len(support.get_lib_ids_by_type(dataset_data, spades_logic.READS_TYPES_USED_IN_RNA_SEQ)):
+            support.error('you cannot specify any data types except ' +
+                          ', '.join(spades_logic.READS_TYPES_USED_IN_RNA_SEQ) + ' in RNA-Seq mode!')
+        if len(support.get_lib_ids_by_type(dataset_data, 'paired-end')) > 1:
+            support.error('you cannot specify more than one paired-end library in RNA-Seq mode!')
+
+    if existing_dataset_data is None:
+        pyyaml.dump(dataset_data, open(options_storage.dataset_yaml_filename, 'w'))
 
     options_storage.set_default_values()
     ### FILLING cfg
@@ -384,13 +424,11 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
     cfg["common"].__dict__["max_threads"] = options_storage.threads
     cfg["common"].__dict__["max_memory"] = options_storage.memory
     cfg["common"].__dict__["developer_mode"] = options_storage.developer_mode
+    if options_storage.series_analysis:
+        cfg["common"].__dict__["series_analysis"] = options_storage.series_analysis
 
     # dataset section
-    cfg["dataset"].__dict__["single_cell"] = options_storage.single_cell
-    cfg["dataset"].__dict__["iontorrent"] = options_storage.iontorrent
-    cfg["dataset"].__dict__["meta"] = options_storage.meta
     cfg["dataset"].__dict__["yaml_filename"] = options_storage.dataset_yaml_filename
-    cfg["dataset"].__dict__["truseq"] = options_storage.truseq_mode
     if options_storage.developer_mode and options_storage.reference:
         cfg["dataset"].__dict__["reference"] = options_storage.reference
 
@@ -404,8 +442,10 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
         if options_storage.bh_heap_check:
             cfg["error_correction"].__dict__["heap_check"] = options_storage.bh_heap_check
         cfg["error_correction"].__dict__["iontorrent"] = options_storage.iontorrent
-        if options_storage.meta:
+        if options_storage.meta or options_storage.large_genome:
             cfg["error_correction"].__dict__["count_filter_singletons"] = 1
+        if options_storage.read_buffer_size:
+            cfg["error_correction"].__dict__["read_buffer_size"] = options_storage.read_buffer_size
 
     # assembly
     if not options_storage.only_error_correction:
@@ -413,9 +453,10 @@ def fill_cfg(options_to_parse, log, secondary_filling=False):
             options_storage.k_mers = None
         if options_storage.k_mers:
             cfg["assembly"].__dict__["iterative_K"] = options_storage.k_mers
+        elif options_storage.rna:
+            cfg["assembly"].__dict__["iterative_K"] = options_storage.K_MERS_RNA
         else:
             cfg["assembly"].__dict__["iterative_K"] = options_storage.K_MERS_SHORT
-        cfg["assembly"].__dict__["careful"] = options_storage.careful
         cfg["assembly"].__dict__["disable_rr"] = options_storage.disable_rr
         cfg["assembly"].__dict__["diploid_mode"] = options_storage.diploid_mode
         cfg["assembly"].__dict__["cov_cutoff"] = options_storage.cov_cutoff
@@ -473,9 +514,11 @@ def check_cfg_for_partial_run(cfg, type='restart-from'):  # restart-from ot stop
                 support.error("failed to " + action + " K=%s because this K " % k_str + verb + " not specified!")
 
 
-def get_options_from_params(params_filename, spades_py_name=None):
+def get_options_from_params(params_filename, running_script):
+    cmd_line = None
+    options = None
     if not os.path.isfile(params_filename):
-        return None, None
+        return cmd_line, options, "failed to parse command line of the previous run (%s not found)!" % params_filename
     params = open(params_filename, 'r')
     cmd_line = params.readline().strip()
     spades_prev_version = None
@@ -485,20 +528,22 @@ def get_options_from_params(params_filename, spades_py_name=None):
             break
     params.close()
     if spades_prev_version is None:
-        support.error("failed to parse SPAdes version of the previous run! "
-                      "Please restart from the beginning or specify another output directory.")
+        return cmd_line, options, "failed to parse SPAdes version of the previous run!"
     if spades_prev_version.strip() != spades_version.strip():
-        support.error("SPAdes version of the previous run (%s) is not equal to the current version of SPAdes (%s)! "
-                      "Please restart from the beginning or specify another output directory."
-                      % (spades_prev_version.strip(), spades_version.strip()))
-    if spades_py_name is None or cmd_line.find(os.path.basename(spades_py_name)) == -1:
-        spades_py_name = 'spades.py'  # try default name
-    else:
-        spades_py_name = os.path.basename(spades_py_name)
-    spades_py_pos = cmd_line.find(spades_py_name)
-    if spades_py_pos == -1:
-        return None, None
-    return cmd_line, cmd_line[spades_py_pos + len(spades_py_name):].split()
+        return cmd_line, options, "SPAdes version of the previous run (%s) is not equal " \
+                                  "to the current version of SPAdes (%s)!" \
+                                  % (spades_prev_version.strip(), spades_version.strip())
+    if 'Command line: ' not in cmd_line or '\t' not in cmd_line:
+        return cmd_line, options, "failed to parse executable script of the previous run!"
+    options = cmd_line.split('\t')[1:]
+    prev_running_script = cmd_line.split('\t')[0][len('Command line: '):]
+    # we cannot restart/continue spades.py run with metaspades.py/rnaspades.py/etc and vice versa
+    if os.path.basename(prev_running_script) != os.path.basename(running_script):
+        return cmd_line, options, "executable script of the previous run (%s) is not equal " \
+                                  "to the current executable script (%s)!" \
+                                  % (os.path.basename(prev_running_script),
+                                     os.path.basename(running_script))
+    return cmd_line, options, ""
 
 
 def show_version():
@@ -532,9 +577,9 @@ def main(args):
     cfg, dataset_data = fill_cfg(options, log)
 
     if options_storage.continue_mode:
-        cmd_line, options = get_options_from_params(os.path.join(options_storage.output_dir, "params.txt"), args[0])
-        if not options:
-            support.error("failed to parse command line of the previous run! Please restart from the beginning or specify another output directory.")
+        cmd_line, options, err_msg = get_options_from_params(os.path.join(options_storage.output_dir, "params.txt"), args[0])
+        if err_msg:
+            support.error(err_msg + " Please restart from the beginning or specify another output directory.")
         cfg, dataset_data = fill_cfg(options, log, secondary_filling=True)
         if options_storage.restart_from:
             check_cfg_for_partial_run(cfg, type='restart-from')
@@ -562,10 +607,10 @@ def main(args):
                 if skip_next or v.startswith('--restart-from='):  # you can specify '--restart-from=k33' but not '-o=out_dir'
                     skip_next = False
                     continue
-                updated_params += " " + v
+                updated_params += "\t" + v
             updated_params = updated_params.strip()
             log.info("with updated parameters: " + updated_params)
-            cmd_line += " " + updated_params
+            cmd_line += "\t" + updated_params
         log.info("")
 
     params_filename = os.path.join(cfg["common"].output_dir, "params.txt")
@@ -583,7 +628,7 @@ def main(args):
                 v = options_storage.dict_of_rel2abs[v]
             if prefix:
                 command += prefix + ":"
-            command += v + " "
+            command += v + "\t"
         log.info(command)
 
     # special case
@@ -623,44 +668,43 @@ def main(args):
             shutil.rmtree(tmp_configs_dir)
         if not os.path.isdir(tmp_configs_dir):
             if options_storage.configs_dir:
-                dir_util.copy_tree(options_storage.configs_dir, tmp_configs_dir, preserve_times=False)
+                dir_util.copy_tree(options_storage.configs_dir, tmp_configs_dir, preserve_times=False, preserve_mode=False)
             else:
-                dir_util.copy_tree(os.path.join(spades_home, "configs"), tmp_configs_dir, preserve_times=False)
+                dir_util.copy_tree(os.path.join(spades_home, "configs"), tmp_configs_dir, preserve_times=False, preserve_mode=False)
 
         corrected_dataset_yaml_filename = ''
         if "error_correction" in cfg:
             STAGE_NAME = "Read error correction"
             bh_cfg = merge_configs(cfg["error_correction"], cfg["common"])
             corrected_dataset_yaml_filename = os.path.join(bh_cfg.output_dir, "corrected.yaml")
+            ec_is_needed = True
+            only_compressing_is_needed = False
             if os.path.isfile(corrected_dataset_yaml_filename) and options_storage.continue_mode \
-                and not options_storage.restart_from == "ec":
-                log.info("\n===== Skipping %s (already processed). \n" % STAGE_NAME)
-            else:
-                support.continue_from_here(log)
-
-                if "HEAPCHECK" in os.environ:
-                    del os.environ["HEAPCHECK"]
-                if "heap_check" in bh_cfg.__dict__:
-                    os.environ["HEAPCHECK"] = bh_cfg.heap_check
-
-                if os.path.exists(bh_cfg.output_dir):
-                    shutil.rmtree(bh_cfg.output_dir)
-                os.makedirs(bh_cfg.output_dir)
-
-                if support.get_lib_ids_by_type(dataset_data, options_storage.LONG_READS_TYPES):
-                    not_used_dataset_data = support.get_libs_by_type(dataset_data, options_storage.LONG_READS_TYPES)
-                    to_correct_dataset_data = support.rm_libs_by_type(dataset_data, options_storage.LONG_READS_TYPES)
-                    to_correct_dataset_yaml_filename = os.path.join(bh_cfg.output_dir, "to_correct.yaml")
-                    pyyaml.dump(to_correct_dataset_data, open(to_correct_dataset_yaml_filename, 'w'))
-                    bh_cfg.__dict__["dataset_yaml_filename"] = to_correct_dataset_yaml_filename
+                    and not options_storage.restart_from == "ec":
+                if not bh_cfg.gzip_output or \
+                        support.dataset_has_gzipped_reads(pyyaml.load(open(corrected_dataset_yaml_filename, 'r'))):
+                    log.info("\n===== Skipping %s (already processed). \n" % STAGE_NAME)
+                    ec_is_needed = False
                 else:
-                    not_used_dataset_data = None
-                    bh_cfg.__dict__["dataset_yaml_filename"] = cfg["dataset"].yaml_filename
+                    only_compressing_is_needed = True
+            if ec_is_needed:
+                if not only_compressing_is_needed:
+                    support.continue_from_here(log)
 
+                    if "HEAPCHECK" in os.environ:
+                        del os.environ["HEAPCHECK"]
+                    if "heap_check" in bh_cfg.__dict__:
+                        os.environ["HEAPCHECK"] = bh_cfg.heap_check
+
+                    if os.path.exists(bh_cfg.output_dir):
+                        shutil.rmtree(bh_cfg.output_dir)
+                    os.makedirs(bh_cfg.output_dir)
+
+                bh_cfg.__dict__["dataset_yaml_filename"] = cfg["dataset"].yaml_filename
                 log.info("\n===== %s started. \n" % STAGE_NAME)
 
-                hammer_logic.run_hammer(corrected_dataset_yaml_filename, tmp_configs_dir, bin_home, bh_cfg, not_used_dataset_data,
-                    ext_python_modules_home, log)
+                hammer_logic.run_hammer(corrected_dataset_yaml_filename, tmp_configs_dir, bin_home, bh_cfg, dataset_data,
+                    ext_python_modules_home, only_compressing_is_needed, log)
                 log.info("\n===== %s finished. \n" % STAGE_NAME)
             if options_storage.stop_after == 'ec':
                 support.finish_here(log)
@@ -668,8 +712,11 @@ def main(args):
         result_contigs_filename = os.path.join(cfg["common"].output_dir, options_storage.contigs_name)
         result_scaffolds_filename = os.path.join(cfg["common"].output_dir, options_storage.scaffolds_name)
         result_assembly_graph_filename = os.path.join(cfg["common"].output_dir, options_storage.assembly_graph_name)
+        result_assembly_graph_filename_gfa = os.path.join(cfg["common"].output_dir, options_storage.assembly_graph_name_gfa)
         result_contigs_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.contigs_paths)
         result_scaffolds_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.scaffolds_paths)
+        result_transcripts_filename = os.path.join(cfg["common"].output_dir, options_storage.transcripts_name)
+        result_transcripts_paths_filename = os.path.join(cfg["common"].output_dir, options_storage.transcripts_paths)
         truseq_long_reads_file_base = os.path.join(cfg["common"].output_dir, "truseq_long_reads")
         truseq_long_reads_file = truseq_long_reads_file_base + ".fasta"
         misc_dir = os.path.join(cfg["common"].output_dir, "misc")
@@ -682,12 +729,16 @@ def main(args):
             spades_cfg.__dict__["result_contigs"] = result_contigs_filename
             spades_cfg.__dict__["result_scaffolds"] = result_scaffolds_filename
             spades_cfg.__dict__["result_graph"] = result_assembly_graph_filename
+            spades_cfg.__dict__["result_graph_gfa"] = result_assembly_graph_filename_gfa
             spades_cfg.__dict__["result_contigs_paths"] = result_contigs_paths_filename
             spades_cfg.__dict__["result_scaffolds_paths"] = result_scaffolds_paths_filename
+            spades_cfg.__dict__["result_transcripts"] = result_transcripts_filename
+            spades_cfg.__dict__["result_transcripts_paths"] = result_transcripts_paths_filename
 
             if options_storage.continue_mode and (os.path.isfile(spades_cfg.result_contigs)
                                                   or ("mismatch_corrector" in cfg and
-                                                      os.path.isfile(assembled_contigs_filename)))\
+                                                      os.path.isfile(assembled_contigs_filename))
+                                                  or (options_storage.truseq_mode and os.path.isfile(assembled_scaffolds_filename)))\
                 and not options_storage.restart_from == 'as' \
                 and not options_storage.restart_from == 'scc' \
                 and not (options_storage.restart_from and options_storage.restart_from.startswith('k')):
@@ -727,9 +778,6 @@ def main(args):
                 if not os.path.isfile(dataset_filename) or not options_storage.continue_mode:
                     dataset_file = open(dataset_filename, 'w')
                     import process_cfg
-                    dataset_file.write("single_cell" + '\t' + process_cfg.bool_to_str(cfg["dataset"].single_cell) + '\n')
-                    dataset_file.write("meta" + '\t' + process_cfg.bool_to_str(cfg["dataset"].meta) + '\n')
-                    dataset_file.write("moleculo" + '\t' + process_cfg.bool_to_str(cfg["dataset"].truseq) + '\n')
                     if os.path.isfile(corrected_dataset_yaml_filename):
                         dataset_file.write("reads" + '\t' + process_cfg.process_spaces(corrected_dataset_yaml_filename) + '\n')
                     else:
@@ -740,7 +788,7 @@ def main(args):
                     dataset_file.close()
                 spades_cfg.__dict__["dataset"] = dataset_filename
 
-                latest_dir = spades_logic.run_spades(tmp_configs_dir, bin_home, spades_cfg, dataset_data, ext_python_modules_home, log)
+                used_K = spades_logic.run_spades(tmp_configs_dir, bin_home, spades_cfg, dataset_data, ext_python_modules_home, log)
 
                 if os.path.isdir(misc_dir) and not options_storage.continue_mode:
                     shutil.rmtree(misc_dir)
@@ -752,7 +800,7 @@ def main(args):
                     if k_str.find(":") != -1:
                         k_str = k_str[:k_str.find(":")]
                     support.error("failed to continue from K=%s because this K was not processed in the original run!" % k_str, log)
-                log.info("\n===== %s finished. \n" % STAGE_NAME)
+                log.info("\n===== %s finished. Used k-mer sizes: %s \n" % (STAGE_NAME, ', '.join(map(str, used_K))))
             if not options_storage.run_completed:
                 if options_storage.stop_after == 'as' or options_storage.stop_after == 'scc' or (options_storage.stop_after and options_storage.stop_after.startswith('k')):
                     support.finish_here(log)
@@ -811,7 +859,9 @@ def main(args):
                         if options_storage.continue_mode and os.path.isfile(corrected):
                             log.info("\n== Skipping processing of " + assembly_type + " (already processed)\n")
                             continue
-
+                        if not os.path.isfile(assembled) or os.path.getsize(assembled) == 0:
+                            log.info("\n== Skipping processing of " + assembly_type + " (empty file)\n")
+                            continue
                         support.continue_from_here(log)
                         log.info("\n== Processing of " + assembly_type + "\n")
 
@@ -822,7 +872,6 @@ def main(args):
                         corr_cfg = merge_configs(cfg["mismatch_corrector"], cfg["common"])
                         
                         result_corrected_filename = os.path.join(tmp_dir_for_corrector, "corrected_contigs.fasta")
-
                         corrector_logic.run_corrector( tmp_configs_dir, bin_home, corr_cfg,
                         ext_python_modules_home, log, assembled, result_corrected_filename)
 
@@ -845,20 +894,32 @@ def main(args):
             if "assembly" in cfg and os.path.isfile(result_contigs_filename):
                 message = " * Assembled contigs are in " + support.process_spaces(result_contigs_filename)
                 log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_scaffolds_filename):
-                message = " * Assembled scaffolds are in " + support.process_spaces(result_scaffolds_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_assembly_graph_filename):
-                message = " * Assembly graph is in " + support.process_spaces(result_assembly_graph_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_contigs_paths_filename):
-                message = " * Paths in the assembly graph corresponding to the contigs are in " + \
-                          support.process_spaces(result_contigs_paths_filename)
-                log.info(message)
-            if "assembly" in cfg and os.path.isfile(result_scaffolds_paths_filename):
-                message = " * Paths in the assembly graph corresponding to the scaffolds are in " + \
-                          support.process_spaces(result_scaffolds_paths_filename)
-                log.info(message)
+            if options_storage.rna:
+                if "assembly" in cfg and os.path.isfile(result_transcripts_filename):
+                    message = " * Assembled transcripts are in " + support.process_spaces(result_transcripts_filename)
+                    log.info(message)
+                if "assembly" in cfg and os.path.isfile(result_transcripts_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the transcripts are in " + \
+                              support.process_spaces(result_transcripts_paths_filename)
+                    log.info(message)
+            else:
+                if "assembly" in cfg and os.path.isfile(result_scaffolds_filename):
+                    message = " * Assembled scaffolds are in " + support.process_spaces(result_scaffolds_filename)
+                    log.info(message)
+                if "assembly" in cfg and os.path.isfile(result_assembly_graph_filename):
+                    message = " * Assembly graph is in " + support.process_spaces(result_assembly_graph_filename)
+                    log.info(message)
+                if "assembly" in cfg and os.path.isfile(result_assembly_graph_filename_gfa):
+                    message = " * Assembly graph in GFA format is in " + support.process_spaces(result_assembly_graph_filename_gfa)
+                    log.info(message)
+                if "assembly" in cfg and os.path.isfile(result_contigs_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the contigs are in " + \
+                              support.process_spaces(result_contigs_paths_filename)
+                    log.info(message)
+                if "assembly" in cfg and os.path.isfile(result_scaffolds_paths_filename):
+                    message = " * Paths in the assembly graph corresponding to the scaffolds are in " + \
+                              support.process_spaces(result_scaffolds_paths_filename)
+                    log.info(message)
             #log.info("")
 
         #breaking scaffolds
@@ -882,13 +943,19 @@ def main(args):
             if options_storage.truseq_mode:
                 if not os.path.isfile(truseq_long_reads_file):
                     support.error("TEST FAILED: %s does not exist!" % truseq_long_reads_file)
+            elif options_storage.rna:
+                if not os.path.isfile(result_transcripts_filename):
+                    support.error("TEST FAILED: %s does not exist!" % result_transcripts_filename)
             else:
                 for result_filename in [result_contigs_filename, result_scaffolds_filename]:
                     if os.path.isfile(result_filename):
                         result_fasta = list(support.read_fasta(result_filename))
                         # correctness check: should be one contig of length 1000 bp
                         correct_number = 1
-                        correct_length = 1000
+                        if options_storage.plasmid:
+                            correct_length = 9667
+                        else:
+                            correct_length = 1000
                         if not len(result_fasta):
                             support.error("TEST FAILED: %s does not contain contigs!" % result_filename)
                         elif len(result_fasta) > correct_number:
