@@ -5,12 +5,12 @@
 //* See file LICENSE for details.
 //***************************************************************************
 
-#include "dev_support/standard_base.hpp"
-#include "io/reads_io/rc_reader_wrapper.hpp"
-#include "io/reads_io/sequence_reader.hpp"
+#include "utils/standard_base.hpp"
+#include "io/reads/rc_reader_wrapper.hpp"
+#include "io/reads/sequence_reader.hpp"
 #include "diff_masking.hpp"
-#include "utils/adt/bag.hpp"
-#include "io/reads_io/vector_reader.hpp"
+#include "common/adt/bag.hpp"
+#include "io/reads/vector_reader.hpp"
 #include "visualization/graph_colorer.hpp"
 
 namespace cap {
@@ -950,7 +950,7 @@ void DrawGraph(const vector<StrandRange>& all_ranges,
                const vector<StrandRange>& full_mosaic_ranges,
                const GenomeBlockComposition& block_composition) {
     make_dir("tmp");
-    graph_pack<Graph, runtime_k::RtSeq> gp(block_composition.block_info().g().k(), "tmp", 0);
+    graph_pack<Graph, RtSeq> gp(block_composition.block_info().g().k(), "tmp", 0);
 
     auto stream = io::RCWrap(StreamInstance(ExtractSequences(all_ranges, block_composition)));
     auto streams = io::ReadStreamList<io::SingleRead>(stream);
@@ -959,9 +959,9 @@ void DrawGraph(const vector<StrandRange>& all_ranges,
 
     auto full_mosaic_pos_stream = io::RCWrap(StreamInstance(ExtractSequences(full_mosaic_ranges, block_composition), mosaic_names(full_mosaic_ranges.size())));
     INFO("Threading " << full_mosaic_ranges.size() << " full mosaics");
-    FillPos(gp, *full_mosaic_pos_stream);
+    visualization::position_filler::FillPos(gp, *full_mosaic_pos_stream);
 
-    omnigraph::DefaultLabeler<Graph> labeler(gp.g, gp.edge_pos);
+    visualization::graph_labeler::DefaultLabeler<Graph> labeler(gp.g, gp.edge_pos);
 
     shared_ptr<GraphSplitter<Graph>> splitter = omnigraph::ReliableSplitter(gp.g,
             numeric_limits<size_t>::max(),
@@ -971,8 +971,8 @@ void DrawGraph(const vector<StrandRange>& all_ranges,
     path::remove_if_exists("mosaic_pics");
     path::make_dir("mosaic_pics");
     INFO("Writing components");
-    omnigraph::visualization::WriteComponents(gp.g, "mosaic_pics/", splitter,
-            omnigraph::visualization::DefaultColorer(gp.g), labeler);
+    visualization::visualization_utils::WriteComponents(gp.g, "mosaic_pics/", splitter,
+            visualization::graph_colorer::DefaultColorer(gp.g), labeler);
     INFO("Components written");
 }
 
