@@ -9,7 +9,7 @@
 #include "../environment.hpp"
 #include "../command.hpp"
 #include "../errors.hpp"
-#include "io/reads_io/wrapper_collection.hpp"
+#include "io/reads/wrapper_collection.hpp"
 
 namespace online_visualization {
 class DrawMisassemblies : public DrawingCommand {
@@ -179,7 +179,7 @@ public:
 
         string file = args[1];
         
-        FillPos(curr_env.graph_pack(), file, "miss", true);
+        visualization::position_filler::FillPos(curr_env.graph_pack(), file, "miss", true);
         cout << "All contigs are mapped" << endl;
 
 
