@@ -7,19 +7,16 @@
 
 #include "gap_closer.hpp"
 #include "assembly_graph/stats/picture_dump.hpp"
-#include "algorithms/simplification/compressor.hpp"
+#include "modules/simplification/compressor.hpp"
 #include "io/dataset_support/read_converter.hpp"
 #include <stack>
 
 namespace debruijn_graph {
 
-template<class Graph, class SequenceMapper>
 class GapCloserPairedIndexFiller {
 private:
-    typedef typename Graph::EdgeId EdgeId;
-    typedef typename Graph::VertexId VertexId;
     const Graph &graph_;
-    const SequenceMapper &mapper_;
+    const SequenceMapper<Graph> &mapper_;
 
     size_t CorrectLength(Path<EdgeId> path, size_t idx) const {
         size_t answer = graph_.length(path[idx]);
@@ -143,13 +140,13 @@ private:
         INFO("Merging paired indices");
         for (auto &index: buffer_pi) {
             paired_index.Merge(index);
-            index.Clear();
+            index.clear();
         }
     }
 
 public:
 
-    GapCloserPairedIndexFiller(const Graph &graph, const SequenceMapper &mapper)
+    GapCloserPairedIndexFiller(const Graph &graph, const SequenceMapper<Graph> &mapper)
             : graph_(graph), mapper_(mapper) { }
 
     /**
@@ -167,11 +164,7 @@ public:
 
 };
 
-template<class Graph, class SequenceMapper>
 class GapCloser {
-public:
-    typedef std::function<bool(const Sequence &)> SequenceCheckF;
-private:
     typedef typename Graph::EdgeId EdgeId;
     typedef typename Graph::VertexId VertexId;
 
@@ -183,22 +176,6 @@ private:
     const int init_gap_val_;
     const omnigraph::de::DEWeight weight_threshold_;
 
-    SequenceMapper mapper_;
-    std::unordered_set<runtime_k::RtSeq> new_kmers_;
-
-    bool CheckNoKmerClash(const Sequence &s) {
-        runtime_k::RtSeq kmer(k_ + 1, s);
-        kmer >>= 'A';
-        for (size_t i = k_; i < s.size(); ++i) {
-            kmer <<= s[i];
-            if (new_kmers_.count(kmer)) {
-                return false;
-            }
-        }
-        std::vector<EdgeId> path = mapper_.MapSequence(s).simple_path();
-        return path.empty();
-    }
-
     std::vector<size_t> DiffPos(const Sequence &s1, const Sequence &s2) const {
         VERIFY(s1.size() == s2.size());
         std::vector<size_t> answer;
@@ -259,67 +236,40 @@ private:
                           : long_seq.Subseq(long_seq.size() - short_seq.size()) == short_seq;
     }
 
-    void AddEdge(VertexId start, VertexId end, const Sequence &s) {
-        runtime_k::RtSeq kmer(k_ + 1, s);
-        kmer >>= 'A';
-        for (size_t i = k_; i < s.size(); ++i) {
-            kmer <<= s[i];
-            new_kmers_.insert(kmer);
-            new_kmers_.insert(!kmer);
-        }
-        g_.AddEdge(start, end, s);
-    }
-
-    bool CorrectLeft(EdgeId first, EdgeId second, int overlap, const vector<size_t> &diff_pos) {
+    void CorrectLeft(EdgeId first, EdgeId second, int overlap, const vector<size_t> &diff_pos) {
         DEBUG("Can correct first with sequence from second.");
         Sequence new_sequence = g_.EdgeNucls(first).Subseq(g_.length(first) - overlap + diff_pos.front(),
                                                            g_.length(first) + k_ - overlap)
                                 + g_.EdgeNucls(second).First(k_);
         DEBUG("Checking new k+1-mers.");
-        if (CheckNoKmerClash(new_sequence)) {
-            DEBUG("Check ok.");
-            DEBUG("Splitting first edge.");
-            pair<EdgeId, EdgeId> split_res = g_.SplitEdge(first, g_.length(first) - overlap + diff_pos.front());
-            first = split_res.first;
-            tips_paired_idx_.Remove(split_res.second);
-            DEBUG("Adding new edge.");
-            VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeEnd(first)), true));
-            VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeStart(second)), false));
-            AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second),
-                    new_sequence);
-            return true;
-        } else {
-            DEBUG("Check fail.");
-            DEBUG("Filled k-mer already present in graph");
-            return false;
-        }
-        return false;
+        DEBUG("Check ok.");
+        DEBUG("Splitting first edge.");
+        pair<EdgeId, EdgeId> split_res = g_.SplitEdge(first, g_.length(first) - overlap + diff_pos.front());
+        first = split_res.first;
+        tips_paired_idx_.Remove(split_res.second);
+        DEBUG("Adding new edge.");
+        VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeEnd(first)), true));
+        VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeStart(second)), false));
+        g_.AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second),
+                new_sequence);
     }
 
-    bool CorrectRight(EdgeId first, EdgeId second, int overlap, const vector<size_t> &diff_pos) {
+    void CorrectRight(EdgeId first, EdgeId second, int overlap, const vector<size_t> &diff_pos) {
         DEBUG("Can correct second with sequence from first.");
         Sequence new_sequence =
                 g_.EdgeNucls(first).Last(k_) + g_.EdgeNucls(second).Subseq(overlap, diff_pos.back() + 1 + k_);
         DEBUG("Checking new k+1-mers.");
-        if (CheckNoKmerClash(new_sequence)) {
-            DEBUG("Check ok.");
-            DEBUG("Splitting second edge.");
-            pair<EdgeId, EdgeId> split_res = g_.SplitEdge(second, diff_pos.back() + 1);
-            second = split_res.second;
-            tips_paired_idx_.Remove(split_res.first);
-            DEBUG("Adding new edge.");
-            VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeEnd(first)), true));
-            VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeStart(second)), false));
+        DEBUG("Check ok.");
+        DEBUG("Splitting second edge.");
+        pair<EdgeId, EdgeId> split_res = g_.SplitEdge(second, diff_pos.back() + 1);
+        second = split_res.second;
+        tips_paired_idx_.Remove(split_res.first);
+        DEBUG("Adding new edge.");
+        VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeEnd(first)), true));
+        VERIFY(MatchesEnd(new_sequence, g_.VertexNucls(g_.EdgeStart(second)), false));
 
-            AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second),
-                    new_sequence);
-            return true;
-        } else {
-            DEBUG("Check fail.");
-            DEBUG("Filled k-mer already present in graph");
-            return false;
-        }
-        return false;
+        g_.AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second),
+                new_sequence);
     }
 
     bool HandlePositiveHammingDistanceCase(EdgeId first, EdgeId second, int overlap) {
@@ -327,9 +277,11 @@ private:
         vector<size_t> diff_pos = DiffPos(g_.EdgeNucls(first).Last(overlap),
                                           g_.EdgeNucls(second).First(overlap));
         if (CanCorrectLeft(first, overlap, diff_pos)) {
-            return CorrectLeft(first, second, overlap, diff_pos);
+            CorrectLeft(first, second, overlap, diff_pos);
+            return true;
         } else if (CanCorrectRight(second, overlap, diff_pos)) {
-            return CorrectRight(first, second, overlap, diff_pos);
+            CorrectRight(first, second, overlap, diff_pos);
+            return true;
         } else {
             DEBUG("Can't correct tips due to the graph structure");
             return false;
@@ -338,6 +290,7 @@ private:
 
     bool HandleSimpleCase(EdgeId first, EdgeId second, int overlap) {
         DEBUG("Match was perfect. No correction needed");
+        DEBUG("Overlap " << overlap);
         //strange info guard
         VERIFY(overlap <= k_);
         if (overlap == k_) {
@@ -347,15 +300,10 @@ private:
         //old code
         Sequence edge_sequence = g_.EdgeNucls(first).Last(k_)
                                  + g_.EdgeNucls(second).Subseq(overlap, k_);
-        if (CheckNoKmerClash(edge_sequence)) {
-            DEBUG("Gap filled: Gap size = " << k_ - overlap << "  Result seq "
-                  << edge_sequence.str());
-            AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second), edge_sequence);
-            return true;
-        } else {
-            DEBUG("Filled k-mer already present in graph");
-            return false;
-        }
+        DEBUG("Gap filled: Gap size = " << k_ - overlap << "  Result seq "
+              << edge_sequence.str());
+        g_.AddEdge(g_.EdgeEnd(first), g_.EdgeStart(second), edge_sequence);
+        return true;
     }
 
     bool ProcessPair(EdgeId first, EdgeId second) {
@@ -367,14 +315,11 @@ private:
             DEBUG("Trying to join conjugate edges " << g_.int_id(first));
             return false;
         }
-        //may be negative!
-        int gap = max(init_gap_val_,
-                      -1 * (int) (min(g_.length(first), g_.length(second)) - 1));
 
         Sequence seq1 = g_.EdgeNucls(first);
         Sequence seq2 = g_.EdgeNucls(second);
-        TRACE("Checking possible gaps from " << gap << " to " << k_ - min_intersection_);
-        for (; gap <= k_ - (int) min_intersection_; ++gap) {
+        TRACE("Checking possible gaps from 1 to " << k_ - min_intersection_);
+        for (int gap = 1; gap <= k_ - (int) min_intersection_; ++gap) {
             int overlap = k_ - gap;
             size_t hamming_distance = HammingDistance(g_.EdgeNucls(first).Last(overlap),
                                                       g_.EdgeNucls(second).First(overlap));
@@ -439,7 +384,6 @@ public:
 
     GapCloser(Graph &g, omnigraph::de::PairedInfoIndexT<Graph> &tips_paired_idx,
               size_t min_intersection, double weight_threshold,
-              const SequenceMapper &mapper,
               size_t hamming_dist_bound = 0 /*min_intersection_ / 5*/)
             : g_(g),
               k_((int) g_.k()),
@@ -447,9 +391,7 @@ public:
               min_intersection_(min_intersection),
               hamming_dist_bound_(hamming_dist_bound),
               init_gap_val_(-10),
-              weight_threshold_(weight_threshold),
-              mapper_(mapper),
-              new_kmers_() {
+              weight_threshold_(weight_threshold)  {
         VERIFY(min_intersection_ < g_.k());
         DEBUG("weight_threshold=" << weight_threshold_);
         DEBUG("min_intersect=" << min_intersection_);
@@ -462,19 +404,17 @@ private:
 
 template<class Streams>
 void CloseGaps(conj_graph_pack &gp, Streams &streams) {
-    typedef NewExtendedSequenceMapper<Graph, Index> Mapper;
     auto mapper = MapperInstance(gp);
-    GapCloserPairedIndexFiller<Graph, Mapper> gcpif(gp.g, *mapper);
+    GapCloserPairedIndexFiller gcpif(gp.g, *mapper);
     PairedIndexT tips_paired_idx(gp.g);
     gcpif.FillIndex(tips_paired_idx, streams);
-    GapCloser<Graph, Mapper> gap_closer(gp.g, tips_paired_idx,
-                                        cfg::get().gc.minimal_intersection, cfg::get().gc.weight_threshold,
-                                        *mapper);
+    GapCloser gap_closer(gp.g, tips_paired_idx,
+                         cfg::get().gc.minimal_intersection, cfg::get().gc.weight_threshold);
     gap_closer.CloseShortGaps();
 }
 
 void GapClosing::run(conj_graph_pack &gp, const char *) {
-    omnigraph::DefaultLabeler<Graph> labeler(gp.g, gp.edge_pos);
+    visualization::graph_labeler::DefaultLabeler<Graph> labeler(gp.g, gp.edge_pos);
     stats::detail_info_printer printer(gp, labeler, cfg::get().output_dir);
     printer(config::info_printer_pos::before_first_gap_closer);
 
