@@ -12,6 +12,7 @@ import os
 import sys
 import shutil
 import support
+import process_cfg
 from site import addsitedir
 from distutils import dir_util
 
@@ -26,7 +27,7 @@ def prepare_config_corr(filename, cfg, ext_python_modules_home):
     data = pyyaml.load(open(filename, 'r'))
     data["dataset"] = cfg.dataset
     data["output_dir"] = cfg.output_dir
-    data["work_dir"] = os.path.join(cfg.output_dir, 'tmp')
+    data["work_dir"] = process_cfg.process_spaces(cfg.tmp_dir)
     #data["hard_memory_limit"] = cfg.max_memory
     data["max_nthreads"] = cfg.max_threads
     data["bwa"] = cfg.bwa
@@ -66,6 +67,9 @@ def run_corrector(configs_dir, execution_home, cfg,
     support.sys_call(command, log)
     if not os.path.isfile(result):
         support.error("Mismatch correction finished abnormally: " + result + " not found!")
+    if os.path.isdir(cfg.tmp_dir):
+        shutil.rmtree(cfg.tmp_dir)
+
 
 
 
