@@ -63,6 +63,8 @@ def prepare_config_spades(filename, cfg, log, additional_contigs_fname, K, stage
     if "bwa_paired" in cfg.__dict__:
         subst_dict["bwa_enable"] = bool_to_str(True)
     subst_dict["path_to_bwa"] =  os.path.join(execution_home, "bwa-spades")
+    if "series_analysis" in cfg.__dict__:
+        subst_dict["series_analysis"] = cfg.series_analysis
     process_cfg.substitute_params(filename, subst_dict, log)
 
 
@@ -120,15 +122,17 @@ def reveal_original_k_mers(RL):
 def add_configs(command, configs_dir):
     #Order matters here!
     mode_config_mapping = [("single_cell", "mda_mode"), 
-                           ("meta", "meta_mode"), 
+                           ("meta", "meta_mode"),
                            ("truseq_mode", "moleculo_mode"),
                            ("rna", "rna_mode"),
+                           ("large_genome", "large_genome_mode"),
                            ("plasmid", "plasmid_mode"),
                            ("careful", "careful_mode"),
                            ("diploid_mode", "diploid_mode")]
-
     for (mode, config) in mode_config_mapping:
         if options_storage.__dict__[mode]:
+            if mode == "rna" or mode == "meta":
+                command.append(os.path.join(configs_dir, "mda_mode.info"))
             command.append(os.path.join(configs_dir, config + ".info"))
     
 
@@ -143,7 +147,8 @@ def run_iteration(configs_dir, execution_home, cfg, log, K, prev_K, last_one):
             (options_storage.restart_from == ("k%d" % K) or options_storage.restart_from.startswith("k%d:" % K))):
             log.info("\n== Skipping assembler: " + ("K%d" % K) + " (already processed)")
             return
-        if options_storage.restart_from and options_storage.restart_from.find(":") != -1:
+        if options_storage.restart_from and options_storage.restart_from.find(":") != -1 \
+                and options_storage.restart_from.startswith("k%d:" % K):
             stage = options_storage.restart_from[options_storage.restart_from.find(":") + 1:]
         support.continue_from_here(log)
 
@@ -237,7 +242,7 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
     used_K = []
 
     # checking and removing conflicting K-mer directories
-    if options_storage.restart_from:
+    if options_storage.restart_from and (options_storage.restart_k_mers != options_storage.original_k_mers):
         processed_K = []
         for k in range(options_storage.MIN_K, options_storage.MAX_K, 2):
             cur_K_dir = os.path.join(cfg.output_dir, "K%d" % k)
@@ -362,6 +367,9 @@ def run_spades(configs_dir, execution_home, cfg, dataset_data, ext_python_module
                 if os.path.isfile(os.path.join(latest, "scaffolds.paths")):
                     if not os.path.isfile(cfg.result_scaffolds_paths) or not options_storage.continue_mode:
                         shutil.copyfile(os.path.join(latest, "scaffolds.paths"), cfg.result_scaffolds_paths)
+            if os.path.isfile(os.path.join(latest, "assembly_graph.gfa")):
+                if not os.path.isfile(cfg.result_graph_gfa) or not options_storage.continue_mode:
+                    shutil.copyfile(os.path.join(latest, "assembly_graph.gfa"), cfg.result_graph_gfa)
             if os.path.isfile(os.path.join(latest, "assembly_graph.fastg")):
                 if not os.path.isfile(cfg.result_graph) or not options_storage.continue_mode:
                     shutil.copyfile(os.path.join(latest, "assembly_graph.fastg"), cfg.result_graph)
